Attribute VB_Name = "ModVar"
Option Explicit

Global NumberOfSources As Integer
Global NumberOfNotes As Integer
Global CurrentSourceCard As Integer
Global SourceCardChanged As Boolean
Global CurrentNoteCard As Integer
Global NoteCardChanged As Boolean
Public Type SourceInfo
    Author As String
    ArticleTitle As String
    Title As String
    Pages As String
End Type
Public Type SourceCard
    BasicInfo As SourceInfo
    Edition As String
    Volume As String
    PublicationType As Integer
    Publication As String
    PublicationDate As String
End Type
Public Type NoteCard
    Source As SourceInfo
    Notes As String
End Type
Global SourceCards(1 To 100) As SourceCard
Global NoteCards(1 To 3000) As NoteCard
Public Type AllCards
    SourceNumber As Integer
    NoteNumber As Integer
    Sources(1 To 100) As SourceCard
    Notes(1 To 3000) As NoteCard
End Type
Global CardDeck As AllCards

Public Sub SyncCards(Operation As String)
    'Syncronizes card stacks for save and load
    Dim a As Integer
    If Operation = "Save" Then 'If preparing to save then
        With CardDeck
            .NoteNumber = NumberOfNotes
            If NumberOfNotes >= 1 Then
                For a = 1 To NumberOfNotes
                    .Notes(a) = NoteCards(a)
                Next a
            End If
            .SourceNumber = NumberOfSources
            If NumberOfSources >= 1 Then
                For a = 1 To NumberOfSources
                    .Sources(a) = SourceCards(a)
                Next a
            End If
        End With
    ElseIf Operation = "Load" Then
        NumberOfNotes = CardDeck.NoteNumber
        If NumberOfNotes >= 1 Then
            For a = 1 To NumberOfNotes
                NoteCards(a) = CardDeck.Notes(a)
            Next a
        End If
        NumberOfSources = CardDeck.SourceNumber
        If NumberOfSources >= 1 Then
            For a = 1 To NumberOfSources
                SourceCards(a) = CardDeck.Sources(a)
            Next a
        End If
    End If
End Sub

Public Sub SaveDeck()
    Dim FileNum As Long, FileName As String, Worked As Boolean
    Worked = True
    If SourceCardChanged Then
        Worked = UpdateCard("Source")
        If Worked Then frmSource.cmdUpdateCard.Enabled = False
    End If
    If NoteCardChanged Then
        Worked = UpdateCard("Note")
        If Worked Then frmNotes.cmdUpdateCard.Enabled = False
    End If
    If Worked Then
        With MDIMain.ComDlg
            .Filter = "Card Decks (*.dek)|*.dek|All Files (*.*)|*.*"
            .ShowSave
        End With
        If MDIMain.ComDlg.FileName <> "" Then
            FileName = MDIMain.ComDlg.FileName
            FileNum = FreeFile()
            SyncCards "Save"
            Open FileName For Binary As #FileNum Len = Len(FileName)
            Put #FileNum, , CardDeck
            Close #FileNum
            MDIMain.Caption = "Note Taker Beta [" & FileName & "]"
        End If
    End If
End Sub

Public Sub LoadDeck()
    Dim FileNum As Long, FileName As String
    With MDIMain.ComDlg
        .Filter = "Card Decks (*.dek)|*.dek|All Files (*.*)|*.*"
        .ShowOpen
    End With
    If MDIMain.ComDlg.FileName <> "" Then
        FileName = MDIMain.ComDlg.FileName
        FileNum = FreeFile()
        Open FileName For Binary As #FileNum Len = Len(FileName)
        Get #FileNum, , CardDeck
        Close #FileNum
        MDIMain.Caption = "Note Taker Beta [" & FileName & "]"
        SyncCards "Load"
        CurrentSourceCard = 1
        RefreshCards
    End If
End Sub

Public Function UpdateCard(CardType As String) As Boolean
    Select Case CardType
        Case "Source"
            If frmSource.txtAuthor.Text <> "" And frmSource.txtTitle.Text <> "" Then
                With SourceCards(CurrentSourceCard)
                    .BasicInfo.Author = frmSource.txtAuthor.Text
                    .BasicInfo.Pages = frmSource.txtPages.Text
                    .BasicInfo.ArticleTitle = frmSource.txtArticleTitle.Text
                    .BasicInfo.Title = frmSource.txtTitle.Text
                    .Edition = frmSource.txtEdition.Text
                    .Volume = frmSource.txtVolume.Text
                    .PublicationType = frmSource.cmbPublicationType.ListIndex
                    .Publication = frmSource.txtPublication.Text
                    .PublicationDate = frmSource.txtPublicationDate.Text
                End With
                SourceCardChanged = False
                RefreshCards
                UpdateCard = True
            ElseIf frmSource.txtAuthor.Text = "" Then
                MsgBox "There is no Author for this source! You need to enter a name for the author.", vbOKOnly + vbExclamation, "Author"
                UpdateCard = False
            ElseIf frmSource.txtTitle.Text = "" Then
                MsgBox "There is no Title for this source! You must enter a title.", vbOKOnly + vbExclamation, "Title"
                UpdateCard = False
            End If
        Case "Note"
            With NoteCards(CurrentNoteCard)
                .Notes = frmNotes.txtNotes.Text
                .Source.ArticleTitle = frmNotes.cmbArticleTitle.Text
                .Source.Author = frmNotes.cmbAuthor.Text
                .Source.Pages = frmNotes.txtPages.Text
                .Source.Title = frmNotes.cmbTitle.Text
            End With
            NoteCardChanged = False
            RefreshCards
            UpdateCard = True
    End Select
End Function

Public Sub RefreshCards()
    Dim a As Integer, b As Integer, AuthorFound As Boolean
    With frmSource
        .txtAuthor.Text = SourceCards(CurrentSourceCard).BasicInfo.Author
        .txtPages.Text = SourceCards(CurrentSourceCard).BasicInfo.Pages
        .txtPublication.Text = SourceCards(CurrentSourceCard).Publication
        .txtPublicationDate.Text = SourceCards(CurrentSourceCard).PublicationDate
        .txtArticleTitle.Text = SourceCards(CurrentSourceCard).BasicInfo.ArticleTitle
        .txtTitle.Text = SourceCards(CurrentSourceCard).BasicInfo.Title
        .txtEdition.Text = SourceCards(CurrentSourceCard).Edition
        .txtVolume.Text = SourceCards(CurrentSourceCard).Volume
        .cmbPublicationType.ListIndex = SourceCards(CurrentSourceCard).PublicationType
        .Caption = "Source Cards [" & CurrentSourceCard & " of " & NumberOfSources & "]"
        .cmdUpdateCard.Enabled = False
        SourceCardChanged = False
        If CurrentSourceCard > 1 Then
            .cmdPrevious.Enabled = True
        Else
            .cmdPrevious.Enabled = False
        End If
        If CurrentSourceCard < NumberOfSources Then
            .cmdNextCard.Enabled = True
        Else
            .cmdNextCard.Enabled = False
        End If
        If NumberOfSources > 1 Then
            .cmdJump.Enabled = True
            .cmdRemoveCard.Enabled = True
        Else
            .cmdJump.Enabled = False
            .cmdRemoveCard.Enabled = False
        End If
        If NumberOfSources < 100 Then
            .cmdNewCard.Enabled = True
        Else
            .cmdNewCard.Enabled = False
        End If
    End With
    With frmNotes
        .cmbAuthor.Clear
        For a = 1 To NumberOfSources
            AuthorFound = False
            For b = -1 To .cmbAuthor.ListCount - 1
                If b > -1 Then
                    .cmbAuthor.ListIndex = b
                    If .cmbAuthor.Text = SourceCards(a).BasicInfo.Author Then
                        AuthorFound = True
                    End If
                End If
            Next b
            If Not AuthorFound And (SourceCards(a).BasicInfo.Author <> "") Then
                .cmbAuthor.AddItem SourceCards(a).BasicInfo.Author
            End If
        Next a
        AuthorFound = False
        For a = -1 To .cmbAuthor.ListCount - 1
            If a > -1 Then
                .cmbAuthor.ListIndex = a
                If .cmbAuthor.Text = NoteCards(CurrentNoteCard).Source.Author Then
                    AuthorFound = True
                End If
                If AuthorFound Then
                    Exit For
                End If
            End If
        Next a
        .txtNotes = NoteCards(CurrentNoteCard).Notes
        .txtPages = NoteCards(CurrentNoteCard).Source.Pages
        .Caption = "Note Cards [" & CurrentNoteCard & " of " & NumberOfNotes & "]"
        NoteCardChanged = False
        .cmdUpdateCard.Enabled = False
        If CurrentNoteCard > 1 Then
            .cmdPreviousCard.Enabled = True
        Else
            .cmdPreviousCard.Enabled = False
        End If
        If CurrentNoteCard < NumberOfNotes Then
            .cmdNextCard.Enabled = True
        Else
            .cmdNextCard.Enabled = False
        End If
        If NumberOfNotes > 1 Then
            .cmdJump.Enabled = True
            .cmdRemoveCard.Enabled = True
        Else
            .cmdJump.Enabled = False
            .cmdRemoveCard.Enabled = False
        End If
        If NumberOfNotes < 3000 Then
            .cmdNewCard.Enabled = True
        Else
            .cmdNewCard.Enabled = False
        End If
    End With
End Sub
